


(function () {

    'use strict';

    var app = angular.module('AR', ['ionic']);

    app.run(function ($ionicPlatform) {
        $ionicPlatform.ready(function () {
            // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
            // for form inputs)
            if (window.cordova && window.cordova.plugins.Keyboard) {
                cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
            }
            if (window.StatusBar) {
                // org.apache.cordova.statusbar required
                StatusBar.styleDefault();
            }
        });
    });

    app.config([
        '$stateProvider', '$urlRouterProvider', '$httpProvider', function ($stateProvider, $urlRouterProvider, $httpProvider) {

            $httpProvider.defaults.useXDomain = true;
            delete $httpProvider.defaults.headers.common['X-Requested-With'];

            $stateProvider
                .state('splash', {
                    url: '/splash',
                    templateUrl: 'views/splash.html',
                    controller: 'splashController'
                })
                .state('main', {
                    url: '/main',
                    templateUrl: 'views/mainContainer.html',
                    abstract: true,
                    controller: 'MainController'
                })
                .state('main.home', {
                    url: '/home',
                    views: {
                        'main': {
                            templateUrl: 'views/home.html',
                            controller: 'HomePageController'
                        }
                    }
                })
                .state('login', {
                    url: '/login',
                    templateUrl: 'views/login.html',
                    controller: 'LoginController'
                })
                .state('main.englishSearch', {
                    url: '/englishSearch',
                    views: {
                        'main': {
                            templateUrl: 'views/englishSearch.html',
                            controller: 'EnglishSearchController'
                        }
                    }
                })
                .state('main.arabicSearch', {
                    url: '/arabicSearch',
                    views: {
                        'main': {
                            templateUrl: 'views/arabicSearch.html',
                            controller: 'ArabicSearchController'
                        }
                    }
                })
                .state('main.categories', {
                    url: '/categories',
                    views: {
                        'main': {
                            templateUrl: 'views/categories.html',
                            controller: 'CategoriesController'
                        }
                    }
                })
                .state('main.categoriesSearchResult', {
                    url: '/categoriesSearchResult',
                    views: {
                        'main': {
                            templateUrl: 'views/categoriesSearchResult.html',
                            controller: 'CategoriesSearchResultController'
                        }
                    }
                })
                .state('main.root', {
                    url: '/root',
                    views: {
                        'main': {
                            templateUrl: 'views/rootSearch.html',
                            controller: 'RootSearchController'
                        }
                    }
                })
                 .state('main.rootKey', {
                     url: '/rootKey',
                     views: {
                         'main': {
                             templateUrl: 'views/rootKey.html',
                             controller: 'RootKeyController'
                         }
                     }
                 })
                .state('main.archive', {
                    url: '/archive',
                    views: {
                        'main': {
                            templateUrl: 'views/archive.html',
                            controller: 'ArchiveController'
                        }
                    }
                })
                 .state('main.archiveWords', {
                     url: '/archiveWords',
                     views: {
                         'main': {
                             templateUrl: 'views/archivewords.html',
                             controller: 'ArchiveWordsController'
                         }
                     }
                 })
                 .state('main.conjugation', {
                     url: '/conjugation/:word/:languageTypeId/:type',
                     views: {
                         'main': {
                             templateUrl: 'views/conjugation.html',
                             controller: 'ConjugationController'
                         }
                     }
                 })
                .state('main.conjugationVerbForms', {
                    url: '/conjugationVerbForms',
                    views: {
                        'main': {
                            templateUrl: 'views/conjugationVerbForms.html',
                            controller: 'ConjugationVerbFormsController'
                        }
                    }
                })
                .state('main.additions', {
                    url: '/additions',
                    views: {
                        'main': {
                            templateUrl: 'views/additions.html',
                            controller: 'AdditionsController'
                        }
                    }
                })

            .state('main.transcriptionEca', {
                url: '/transcriptionEca',
                views: {
                    'main': {
                        templateUrl: 'views/transcriptionEca.html',
                        controller: 'TranscriptionEcaController'
                    }
                }
            })
                .state('main.transcriptionMsa', {
                    url: '/transcriptionMsa',
                    views: {
                        'main': {
                            templateUrl: 'views/transcriptionMsa.html',
                            controller: 'TranscriptionMsaController'
                        }
                    }
                })

             .state('main.patternMsa', {
                 url: '/patternMsa',
                 views: {
                     'main': {
                         templateUrl: 'views/patternMsa.html',
                         controller: 'PatternMsaController'
                     }
                 }
             })

             .state('main.patternEca', {
                 url: '/patternEca',
                 views: {
                     'main': {
                         templateUrl: 'views/patternEca.html',
                         controller: 'PatternEcaController'
                     }
                 }
             });

            $urlRouterProvider.otherwise('/splash');
        }
    ]);

})();



    
