(function () {
    'use strict';
    angular.module('AR').controller('ArabicSearchController', function ($scope, $state, $location, api, Collations, scriptTypes, $ionicPopup, $sce, localStorage, $stateParams) {


        $scope.navTitle = 'Arabic Word Search';
        $scope.model = {}
        $scope.errorMessage = '';
        $scope.isConjugationEnabled = false;
        $scope.isTranscriptionEnabled = false;

        $scope.offensive = false;

        $scope.model.scriptTypes = scriptTypes;
        $scope.model.Collations = Collations;
        $scope.model.heighlight = 'heighlight';

        $scope.model.showEmptyResultMessage = false;

        $scope.model.collation =  $scope.model.Collations.filter(function (c) { return c.isDefault === true; })[0].key;
        $scope.model.selectedScriptType = $scope.model.scriptTypes.filter(function (c) { return c.isDefault === true; })[0].key;



        $scope.model.resultsAvailable = function () { return $scope.model.searchResults != null && $scope.model.searchResults.length > 0; };

        $scope.Init = function () {


            $scope.model.showEmptyResultMessage = false;
            $scope.model.searchResults = {}
            $scope.errorMessage = '';

            if (window.localStorage.getItem("isInit") != "true") {

                $scope.model.searchKeyword = window.localStorage.getItem("searchKeyword_Arabic");
                $scope.model.collation = window.localStorage.getItem("collation_Arabic");
                $scope.model.selectedScriptType = window.localStorage.getItem("selectedScriptType_Arabic");

                api.FetchArabicResult($scope.model.searchKeyword, $scope.model.collation).then(function (data) {
                    $scope.model.searchResults = data.ArabicWordSearchResultItems;
                    $scope.isConjugationEnabled = data.ConjugationButton;
                    $scope.offensive = data.Offensive;

                    if ($scope.model.searchResults == null || $scope.model.searchResults.length == 0) {
                        $scope.model.showEmptyResultMessage = true;
                        $scope.isTranscriptionEnabled = false;

                    } else {
                        $scope.model.showEmptyResultMessage = false;
                        $scope.isTranscriptionEnabled = true;

                    }

                });

            };
        }

        $scope.Init();


        $scope.Search = function () {
            $scope.model.showEmptyResultMessage = false;
            $scope.model.searchResults = {}
            $scope.errorMessage = '';
            //$scope.model.searchKeyword = VKI_targetword.value;

            if ($scope.model.searchKeyword == "") {
                $scope.errorMessage = "Search Keyword is required";
            } else {

                //$location.path('/main/arkabicSearch/' + $scope.model.searchKeyword + '/' + $scope.model.collation + '/' + $scope.model.selectedScriptType);

                window.localStorage.setItem("searchKeyword_Arabic", $scope.model.searchKeyword);
                window.localStorage.setItem("collation_Arabic", $scope.model.collation);
                window.localStorage.setItem("selectedScriptType_Arabic", $scope.model.selectedScriptType);
                window.localStorage.setItem("isInit", "false");

                api.FetchArabicResult($scope.model.searchKeyword, $scope.model.collation).then(function (data) {
                    $scope.model.searchResults = data.ArabicWordSearchResultItems;
                    $scope.isConjugationEnabled = data.ConjugationButton;
                    $scope.offensive = data.Offensive;

                    if ($scope.model.searchResults == null || $scope.model.searchResults.length == 0) {
                        $scope.model.showEmptyResultMessage = true;
                        $scope.isTranscriptionEnabled = false;

                    } else {
                        $scope.model.showEmptyResultMessage = false;
                        $scope.isTranscriptionEnabled = true;

                    }

                });
            }
        }

        $scope.ShowConjugation = function () {

            $location.path('/main/conjugation/' + $scope.model.searchKeyword + '/' + $scope.model.collation + '/2');

        };

        $scope.ShowTranscription = function () {

            if ($scope.model.collation == 2) {

                $location.path('/main/transcriptionEca');


            } else {
                $location.path('/main/transcriptionMsa');

            }
        };

        $scope.showPopup = function (enItem) {

            var isArabicScript = $scope.model.selectedScriptType == 1;

            api.PlayAudio(true, enItem.FileName).
                 then(function (data) {
                     data.IsArabic = isArabicScript;
                     $scope.data = data;
                     // An elaborate, custom popup
                     var myPopup = $ionicPopup.show({
                         templateUrl: 'views/audio.html',
                         title: 'Play Audio',
                         //subTitle: 'Please use normal things',
                         scope: $scope,
                         buttons: [
                           {
                               text: '<b>close</b>',
                               type: 'button-calm',
                           },
                         ]
                     });
                 });

        };

        $scope.addToArchive = function (enItem) {
            var user = localStorage.GetLoggedInUserInfo();
            var script = $scope.model.selectedScriptType == 1 ? enItem.ArabicScript : enItem.ArabicTransScript;
            api.GetArchieveWordData(enItem.Id, enItem.Definition, script, user.id).
               then(function (data) {

                   if (data.ArchieveFileDtos.length == 0) {


                       var alertPopup = $ionicPopup.alert({
                           title: 'Alert',
                           template: 'You have to create archive first. !'
                       });


                       return;
                   } else {

                       $scope.data = data;
                       $scope.data.selectedFileId = $scope.data.ArchieveFileDtos[0].FileId;
                       // An elaborate, custom popup
                       var myPopup = $ionicPopup.show({
                           templateUrl: 'views/addToArchive.html',
                           title: 'Add To Archive',
                           //subTitle: 'Please use normal things',
                           scope: $scope,
                           buttons: [
                               {
                                   text: '<b>Save</b>',
                                   type: 'button-calm',
                                   onTap: function () {
                                       var param = { FileId: $scope.data.selectedFileId, SubentryId: $scope.data.SubentryId };
                                       api.AddWordToArchive(param).then(function (result) {
                                           console.log(result);
                                           if (!result.IsSuccess) {
                                               $ionicPopup.alert({
                                                   title: 'Error !',
                                                   template: result.Message
                                               });
                                           } else {
                                               $ionicPopup.alert({
                                                   title: 'Confirmation',
                                                   template: result.Message
                                               });
                                           }
                                       });
                                   }
                               }
                               ,
                                  {

                                      text: '<b>Cancel</b>',
                                      type: 'bar-light'
                                  }
                           ]
                       });
                   }
               });
        };
    });
})();
