(function () {
    'use strict';
    angular.module('AR').controller('RootSearchController', function ($scope, $stateParams, $state, $location, api, Collations, scriptTypes, $ionicPopup, $sce, localStorage) {
        $scope.navTitle = 'Arabic Root Search';
        $scope.model = {};
        $scope.errorMessage = '';
        $scope.isConjugationEnabled = false;
        $scope.isTranscriptionEnabled = false;

        $scope.offensive = false;
        $scope.model.heighlight = 'heighlight';


        $scope.model.scriptTypes = scriptTypes;
        $scope.model.Collations = Collations;


        $scope.model.collation = $scope.model.Collations.filter(function (c) { return c.isDefault === true; })[0].key;
        $scope.model.selectedScriptType = $scope.model.scriptTypes.filter(function (c) { return c.isDefault === true; })[0].key;

        $scope.model.showEmptyResultMessage = false;

       

        $scope.model.resultsAvailable = function () { return $scope.model.searchResults != null && $scope.model.searchResults.length > 0 };

        $scope.Init = function () {

            $scope.model.showEmptyResultMessage = false;

            if (window.localStorage.getItem("isInit") != "true") {


                $scope.model.searchKeyword = window.localStorage.getItem("searchKeyword_Root");
                $scope.model.collation = window.localStorage.getItem("collation_Root");
                $scope.model.selectedScriptType = window.localStorage.getItem("selectedScriptType_Root");

                var word = $scope.model.searchKeyword;
                word = word.trim();

                $scope.model.searchKeyword = word;

                api.FetchRootResult($scope.model.searchKeyword, $scope.model.collation).then(function (data) {
                    $scope.model.searchResults = data.ArabicRootSearchResultItems;
                    $scope.isConjugationEnabled = data.ConjugationButton;
                    $scope.offensive = data.Offensive;

                    if ($scope.model.searchResults == null || $scope.model.searchResults.length == 0) {
                        $scope.model.showEmptyResultMessage = true;
                        $scope.isTranscriptionEnabled = false;

                    } else {
                        $scope.model.showEmptyResultMessage = false;
                        $scope.isTranscriptionEnabled = true;
                    }
                });


            };
        };

        $scope.Init();

        $scope.Search = function () {

            $scope.errorMessage = '';
            //$scope.model.searchKeyword = VKI_target.value;
            if ($scope.model.searchKeyword == "") {
                $scope.errorMessage = "Search Keyword is required";
            } else {

                //$location.path('/main/root/' + $scope.model.searchKeyword + '/' + $scope.model.collation + '/'
                //    + $scope.model.selectedScriptType);

               
                window.localStorage.setItem("searchKeyword_Root", $scope.model.searchKeyword);
                window.localStorage.setItem("collation_Root", $scope.model.collation);
                window.localStorage.setItem("selectedScriptType_Root", $scope.model.selectedScriptType);
                window.localStorage.setItem("isInit", "false");


                var word = $scope.model.searchKeyword;
                word = word.trim();

                $scope.model.searchKeyword = word;

                api.FetchRootResult($scope.model.searchKeyword, $scope.model.collation).then(function (data) {
                    $scope.model.searchResults = data.ArabicRootSearchResultItems;
                    $scope.isConjugationEnabled = data.ConjugationButton;
                    $scope.offensive = data.Offensive;

                    if ($scope.model.searchResults == null || $scope.model.searchResults.length == 0) {
                        $scope.model.showEmptyResultMessage = true;
                        $scope.isTranscriptionEnabled = false;

                    } else {
                        $scope.model.showEmptyResultMessage = false;
                        $scope.isTranscriptionEnabled = true;
                    }
                });
            }
        };

        $scope.ShowConjugation = function () {

            $location.path('/main/conjugation/' + $scope.model.searchKeyword + '/' + $scope.model.collation + '/1');

            //$location.path('/main/conjugation').search({
            //    'word': $scope.model.searchKeyword,
            //    'languageTypeId': $scope.model.collation,
            //    type: "1"
            //});
        };

        $scope.ShowTranscription = function () {

            if ($scope.model.collation == 2) {

                $location.path('/main/transcriptionEca');


            } else {
                $location.path('/main/transcriptionMsa');

            }
        };

        $scope.showPopup = function (enItem) {

            var isArabicScript = $scope.model.selectedScriptType == 1;

            api.PlayAudio(true, enItem.FileName).
                 then(function (data) {
                     data.IsArabic = isArabicScript;
                     $scope.data = data;
                     // An elaborate, custom popup
                     var myPopup = $ionicPopup.show({
                         templateUrl: 'views/audio.html',
                         title: 'Play Audio',
                         //subTitle: 'Please use normal things',
                         scope: $scope,
                         buttons: [
                           {
                               text: '<b>close</b>',
                               type: 'button-calm',
                           },
                         ]
                     });
                 });

        };

        $scope.addToArchive = function (enItem) {
            var user = localStorage.GetLoggedInUserInfo();
            var script = $scope.model.selectedScriptType == 1 ? enItem.ArabicScript : enItem.ArabicTransScript;
            api.GetArchieveWordData(enItem.Id, enItem.Definition, script, user.id).
               then(function (data) {


                   if (data.ArchieveFileDtos.length == 0) {


                       var alertPopup = $ionicPopup.alert({
                           title: 'Alert',
                           template: 'You have to create archive first. !'
                       });


                       return;
                   } else {

                       $scope.data = data;
                       $scope.data.selectedFileId = $scope.data.ArchieveFileDtos[0].FileId;
                       // An elaborate, custom popup
                       var myPopup = $ionicPopup.show({
                           templateUrl: 'views/addToArchive.html',
                           title: 'Add To Archive',
                           //subTitle: 'Please use normal things',
                           scope: $scope,
                           buttons: [
                               {
                                   text: '<b>Save</b>',
                                   type: 'button-calm',
                                   onTap: function () {
                                       var param = { FileId: $scope.data.selectedFileId, SubentryId: $scope.data.SubentryId };
                                       api.AddWordToArchive(param).then(function (result) {
                                           if (!result.IsSuccess) {
                                               $ionicPopup.alert({
                                                   title: 'Error !',
                                                   template: result.Message
                                               });
                                           } else {
                                               $ionicPopup.alert({
                                                   title: 'Confirmation',
                                                   template: result.Message
                                               });
                                           }
                                       });
                                   }
                               }
                               ,
                                    {

                                        text: '<b>Cancel</b>',
                                        type: 'bar-light'
                                    }
                           ]

                       });
                   }
               });
        };

        //$("#rootkeytxtbox").change(function () {

        //    var word = $('#rootkeytxtbox').val();
        //    var wordWithSpaces = '';
        //    for (var i = 0; i < word.length; i++) {
        //        wordWithSpaces += word[i] + ' ';
        //    }

        //    wordWithSpaces = wordWithSpaces.trim();

        //    $scope.model.searchKeyword = wordWithSpaces;

        //});

    });
})();
