(function () {
    'use strict';
    var ar = angular.module('AR');
    ar.factory('localStorage', function (api, $q) {
        return {

            StoreLoggedInUserInfo: function (userId, userName, password, isPowerAdmin) {

                var words = [];
                var files;

                api.FetchArchiveFiles(userId).then(function (data) {
                    var deferred = $q.defer();

                    files = data.ArchieveFileDtos;
                    var filesLength = files.length;
                    var i = 0;
                    angular.forEach(data.ArchieveFileDtos, function (file, key) {
                        i++;
                        api.FetchArchiveWords(file.FileId).then(function (result) {
                            var wordsToSave = result.ArchiveSubentryDtos;
                            angular.forEach(wordsToSave, function (word, k) {

                                var wordObj = {
                                    FileId : file.FileId,
                                    SubId: word.Id,
                                    English: word.English,
                                    ArabicScript: word.ArabicScript,
                                    ArabicTranscript: word.ArabicTranscript,
                                    Offensive: word.Offensive,
                                    RootKey: word.RootKey,
                                    RootNumber: word.RootNumber,
                                    AudioFile: word.AudioFile,
                                    LanguageTypeId: word.LanguageTypeId,
                                };
                                words.push(wordObj);
                            });
                            if (i == filesLength) deferred.resolve();
                        });


                    });
                    return deferred.promise;

                }).then(function () {


                    var lib = new localStorageDB("arootLibrary", localStorage);

                    //Create Storage if it's not exist

                    if (lib.isNew()) {

                        lib.createTable("loggedInUser", ["id", "name", "password","isPowerAdmin"]);
                        lib.createTable("file", ["FileId", "FileName", "userId", "WordsCount"]);
                        lib.createTable("word", ["id", "english", "arabicScript", "arabicTranscript", "offensive", "rootKey",
                            "rootNumber","audioFile","languageTypeId",
                            "fileId"]);

                    } else {

                        //drop the Storage if it's exist

                        lib.drop();
                        lib = new localStorageDB("arootLibrary", localStorage);
                        lib.createTable("loggedInUser", ["id", "name", "password", "isPowerAdmin"]);
                        lib.createTable("file", ["FileId", "FileName", "userId", "WordsCount"]);
                        lib.createTable("word", ["id", "english", "arabicScript", "arabicTranscript", "offensive", "rootKey",
                            "rootNumber", "audioFile", "languageTypeId", "fileId"]);
                    }

                    lib.commit();


                    //Store Info for loggedIn User

                    lib.insert("loggedInUser", { id: userId, name: userName, password: password, isPowerAdmin: isPowerAdmin });
                    lib.commit();


                    //Store Archive data
                    angular.forEach(files, function (file, key) {
                        lib.insert("file", { FileId: file.FileId, FileName: file.FileName, userId: userId, WordsCount: file.WordsCount });
                    });

                    angular.forEach(words, function (word, key) {
                        lib.insert("word", { id: word.SubId, english: word.English, arabicScript: word.ArabicScript,
                            arabicTranscript :word.ArabicTranscript,offensive : word.Offensive,rootKey: word.RootKey,
                            rootNumber: word.RootNumber,audioFile: word.AudioFile,languageTypeId: word.LanguageTypeId,
                            fileId: word.FileId
                        });
                    });

                    lib.commit();
                });

            },


            GetLoggedInUserInfo: function() {
                var lib = new localStorageDB("arootLibrary", localStorage);
                return lib.query("loggedInUser")[0];
            },

            GetLoggedInUserArchivedFiles: function (userId) {
                
                var lib = new localStorageDB("arootLibrary", localStorage);

               return  lib.query("file", { userId: userId });
            },

            LogOut: function() {
                
                var lib = new localStorageDB("arootLibrary", localStorage);
                lib.truncate('loggedInUser');
                lib.commit();

                console.log("afterlogout");
                console.log(lib.query("loggedInUser")[0]);
            },



        };
    });

})();